summaryrefslogtreecommitdiffstats
path: root/tests
diff options
context:
space:
mode:
authorAndrey Andreev <narf@devilix.net>2017-01-10 11:22:05 +0100
committerAndrey Andreev <narf@devilix.net>2017-01-10 11:22:05 +0100
commitfa986fe738363069d8ae331f0ae331521cd895d3 (patch)
tree61ca5ddf932b9deca0fec6eab0da094937cc26bd /tests
parent0bbfff9f7ddc8a3994f5ed2ba320b4bbdd2205b9 (diff)
Add a testcase and changelog entry for #4975
Diffstat (limited to 'tests')
-rw-r--r--tests/codeigniter/core/Loader_test.php6
1 files changed, 4 insertions, 2 deletions
diff --git a/tests/codeigniter/core/Loader_test.php b/tests/codeigniter/core/Loader_test.php
index c1c4997c4..241c415b3 100644
--- a/tests/codeigniter/core/Loader_test.php
+++ b/tests/codeigniter/core/Loader_test.php
@@ -295,8 +295,10 @@ class Loader_test extends CI_TestCase {
$output->expects($this->once())->method('append_output')->with($content.$value);
$this->ci_instance_var('output', $output);
- // Test view output
- $this->assertInstanceOf('CI_Loader', $this->load->view($view, array($var => $value)));
+ // Test view output and $vars as an object
+ $vars = new stdClass();
+ $vars->$var = $value;
+ $this->assertInstanceOf('CI_Loader', $this->load->view($view, $vars));
}
// --------------------------------------------------------------------